Compression - kombu.compression — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Compression - kombu.compression

`kombu.compression.` `compress`(body, content_type)

`kombu.compression.` `decompress`(body, content_type)

`kombu.compression.` `get_decoder`(t)

`kombu.compression.` `get_encoder`(t)

`kombu.compression.` `register`(encoder, decoder, content_type, aliases=[])

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »